diff --git a/LUFA/Drivers/Board/Temperature.c b/LUFA/Drivers/Board/Temperature.c
index 3c8028143cc666fd1c3b6baee067fa4eb6d55d65..e95b4ba99d2e840f2d84c69d512e357b8dcb173d 100644
--- a/LUFA/Drivers/Board/Temperature.c
+++ b/LUFA/Drivers/Board/Temperature.c
@@ -30,7 +30,7 @@
 
 #include "Temperature.h"
 
-static const uint16_t PROGMEM Temperature_Lookup[] = {
+static const uint16_t PROGMEM Temperature_Lookup[TEMP_TABLE_SIZE] = {
    0x3B4, 0x3B0, 0x3AB, 0x3A6, 0x3A0, 0x39A, 0x394, 0x38E, 0x388, 0x381, 0x37A, 0x373,
    0x36B, 0x363, 0x35B, 0x353, 0x34A, 0x341, 0x338, 0x32F, 0x325, 0x31B, 0x311, 0x307,
    0x2FC, 0x2F1, 0x2E6, 0x2DB, 0x2D0, 0x2C4, 0x2B8, 0x2AC, 0x2A0, 0x294, 0x288, 0x27C,
@@ -50,7 +50,7 @@ int8_t Temperature_GetTemperature(void)
 	if (Temp_ADC > pgm_read_word(&Temperature_Lookup[0]))
 	  return TEMP_MIN_TEMP;
 
-	for (uint16_t Index = 0; Index < (sizeof(Temperature_Lookup) / sizeof(Temperature_Lookup[0])); Index++)
+	for (uint16_t Index = 0; Index < TEMP_TABLE_SIZE; Index++)
 	{
 		if (Temp_ADC > pgm_read_word(&Temperature_Lookup[Index]))
 		  return (Index + TEMP_TABLE_OFFSET_DEGREES);
diff --git a/LUFA/Drivers/Board/Temperature.h b/LUFA/Drivers/Board/Temperature.h
index fa86ccd244312d229127502d437a7e0436de4109..ef76ece27e1f9a1e22dae838829344015607abc7 100644
--- a/LUFA/Drivers/Board/Temperature.h
+++ b/LUFA/Drivers/Board/Temperature.h
@@ -92,12 +92,15 @@
 
 			/** ADC channel MUX mask for the temperature sensor. */
 			#define TEMP_ADC_CHANNEL_MASK  ADC_CHANNEL0
+			
+			/** Size of the temperature sensor lookup table, in lookup values */
+			#define TEMP_TABLE_SIZE        120
 
 			/** Minimum returnable temperature from the \ref Temperature_GetTemperature() function. */
-			#define TEMP_MIN_TEMP          TEMP_TABLE_OFFSET
+			#define TEMP_MIN_TEMP          TEMP_TABLE_OFFSET_DEGREES
 
 			/** Maximum returnable temperature from the \ref Temperature_GetTemperature() function. */
-			#define TEMP_MAX_TEMP          ((TEMP_TABLE_SIZE - 1) + TEMP_TABLE_OFFSET)
+			#define TEMP_MAX_TEMP          ((TEMP_TABLE_SIZE - 1) + TEMP_TABLE_OFFSET_DEGREES)
 
 		/* Inline Functions: */
 			/** Initialises the temperature sensor driver, including setting up the appropriate ADC channel.
diff --git a/LUFA/Drivers/Peripheral/SerialStream.h b/LUFA/Drivers/Peripheral/SerialStream.h
index 3ea165066267b842305f5cbbc6e26a80da25eb51..577d675373ec8e256e07aa12e37a88f73a5d7c2a 100644
--- a/LUFA/Drivers/Peripheral/SerialStream.h
+++ b/LUFA/Drivers/Peripheral/SerialStream.h
@@ -97,6 +97,13 @@
 	#endif
 
 	/* Public Interface - May be used in end-application: */
+		/* External Variables: */
+			/** Named stream for the USART, once \ref SerialStream_Init() has been called. This may be used with the
+			 *  file based stream functions (fprintf, fscanf, etc.) that require a handle to the stream rather than
+			 *  using the stdin and stdout named streams.
+			 */
+			extern FILE USARTStream;
+
 		/* Inline Functions: */
 			/** Initialises the serial stream (and regular USART driver) so that both the stream and regular
 			 *  USART driver functions can be used. Must be called before any stream or regular USART functions.
@@ -121,13 +128,6 @@
 				Serial_ShutDown();
 			}
 
-		/* External Variables: */
-			/** Named stream for the USART, once \ref SerialStream_Init() has been called. This may be used with the
-			 *  file based stream functions (fprintf, fscanf, etc.) that require a handle to the stream rather than
-			 *  using the stdin and stdout named streams.
-			 */
-			extern FILE USARTStream;
-
 	/* Disable C linkage for C++ Compilers: */
 		#if defined(__cplusplus)
 			}
diff --git a/LUFA/Common/Common.h b/LUFA/Common/Common.h
index 1e9e9663f5f17b502dcfda30b8947e7600093e5d..d2d91fb3760bcc1ea25eb27efb4b13c90b9ff8f6 100644
--- a/LUFA/Common/Common.h
+++ b/LUFA/Common/Common.h
@@ -106,7 +106,7 @@
 			 *  must be pre-initialized before this macro is run and linked to an output device, such as the AVR's USART
 			 *  peripheral.
 			 *
 			 *  The output takes the form "{FILENAME}: Function {FUNCTION NAME}, Line {LINE NUMBER}: Assertion {x} failed."
 			 *
 			 *  \param[in] Condition  Condition that will be evaluated,
 			 *
@@ -114,7 +114,7 @@
 			 */
 			#define STDOUT_ASSERT(Condition)        MACROS{ if (!(x)) { printf_P(PSTR("%s: Function \"%s\", Line %d: "   \
 			                                                "Assertion \"%s\" failed.\r\n"),     \
-			                                                __FILE__, __func__, __LINE__, #x); } }MACROE
+			                                                __FILE__, __func__, __LINE__, #Condition); } }MACROE
 			
 			/** Forces GCC to use pointer indirection (via the AVR's pointer register pairs) when accessing the given
 			 *  struct pointer. In some cases GCC will emit non-optimal assembly code when accessing a structure through
@@ -106,7 +106,7 @@
 			 *  peripheral.
 			 *
-			 *  The output takes the form "{FILENAME}: Function {FUNCTION NAME}, Line {LINE NUMBER}: Assertion {x} failed."
+			 *  The output takes the form "{FILENAME}: Function {FUNCTION NAME}, Line {LINE NUMBER}: Assertion {Condition} failed."
 			 *
 			 *  \param[in] Condition  Condition that will be evaluated,